package pomodoro

import (
	"github.com/gorilla/websocket"
	"sync"
)

const (
	workDuration       = 15 * 60
	shortBreakDuration = 5 * 60
	longBreakDuration  = 10 * 60
	sessions           = 4
)

var mu sync.Mutex // to synchronize access to shared state

// RunPomodoroTimer iterates the Pomodoro work/break sessions.
func RunPomodoroTimer(clients map[*websocket.Conn]bool) {
	mu.Lock()
	timerRunning = true

	for session := 1; session <= sessions; session++ {
		if !startTimer(clients, workDuration, "Work", session) {
			break
		}
		if session == sessions {
			if !startTimer(clients, longBreakDuration, "LongBreak", session) {
				break
			}
		} else {
			if !startTimer(clients, shortBreakDuration, "ShortBreak", session) {
				break
			}
		}
	}

	timerRunning = false
	mu.Unlock()
}
