package websocket

import (
	"github.com/gorilla/websocket"
	"log"
	"net/http"
)

// Map to track connected clients
var Clients = make(map[*websocket.Conn]bool)

// Upgrader to upgrade HTTP requests to WebSocket connections
var upgrader = websocket.Upgrader{
	CheckOrigin: func(r *http.Request) bool { return true },
}

// HandleConnections upgrades HTTP requests to WebSocket connections and manages the client lifecycle.
func HandleConnections(w http.ResponseWriter, r *http.Request) {
	// Upgrade initial GET request to a WebSocket
	ws, err := upgrader.Upgrade(w, r, nil)
	if err != nil {
		log.Printf("WebSocket upgrade error: %v", err)
		return
	}
	defer ws.Close()

	// Register the new client
	Clients[ws] = true

	// Listen for commands from the connected client
	handleClientCommands(ws)
}
